@@ -91,7 +91,7 @@ class Mandrill(object):
         params = json.dumps(params)
         self.log('POST to %s%s.json: %s' % (ROOT, url, params))
         start = time.time()
-        r = self.session.post('%s%s.json' % (ROOT, url), data=params, headers={'content-type': 'application/json', 'user-agent': 'Mandrill-Python/1.0.16'})
+        r = self.session.post('%s%s.json' % (ROOT, url), data=params, headers={'content-type': 'application/json', 'user-agent': 'Mandrill-Python/1.0.19'})
         try:
             remote_addr = r.raw._original_response.fp._sock.getpeername() # grab the remote_addr before grabbing the text since the socket will go away
         except:
@@ -102,7 +102,12 @@ class Mandrill(object):
         self.log('Received %s in %.2fms: %s' % (r.status_code, complete_time * 1000, r.text))
         self.last_request = {'url': url, 'request_body': params, 'response_body': r.text, 'remote_addr': remote_addr, 'response': r, 'time': complete_time}
 
-        result = r.json
+        # requests 1.0.0 changed this from a property to a function
+        if callable(r.json):
+            result = r.json()
+        else:
+            result = r.json
+
         if r.status_code != requests.codes.ok:
             raise self.cast_error(result)
         return result
@@ -847,6 +852,7 @@ class Messages(object):
                message.track_opens (boolean): whether or not to turn on open tracking for the message
                message.track_clicks (boolean): whether or not to turn on click tracking for the message
                message.auto_text (boolean): whether or not to automatically generate a text part for messages that are not given text
+               message.inline_css (boolean): whether or not to automatically inline all CSS styles provided in the message HTML - only for HTML documents less than 256KB in size
                message.url_strip_qs (boolean): whether or not to strip the query string from URLs when aggregating tracked URL data
                message.preserve_recipients (boolean): whether or not to expose all recipients in to "To" header for each email
                message.bcc_address (string): an optional address to receive an exact copy of each recipient's email
@@ -901,6 +907,7 @@ class Messages(object):
                [] (struct): the sending results for a single recipient::
                    [].email (string): the email address of the recipient
                    [].status (string): the sending status of the recipient - either "sent", "queued", "rejected", or "invalid"
+                   []._id (string): the message's unique id
 
 
         Raises:
@@ -935,6 +942,7 @@ class Messages(object):
                message.track_opens (boolean): whether or not to turn on open tracking for the message
                message.track_clicks (boolean): whether or not to turn on click tracking for the message
                message.auto_text (boolean): whether or not to automatically generate a text part for messages that are not given text
+               message.inline_css (boolean): whether or not to automatically inline all CSS styles provided in the message HTML - only for HTML documents less than 256KB in size
                message.url_strip_qs (boolean): whether or not to strip the query string from URLs when aggregating tracked URL data
                message.preserve_recipients (boolean): whether or not to expose all recipients in to "To" header for each email
                message.bcc_address (string): an optional address to receive an exact copy of each recipient's email
@@ -988,6 +996,7 @@ class Messages(object):
                [] (struct): the sending results for a single recipient::
                    [].email (string): the email address of the recipient
                    [].status (string): the sending status of the recipient - either "sent", "queued", "rejected", or "invalid"
+                   []._id (string): the message's unique id
 
 
         Raises:
@@ -1092,6 +1101,7 @@ class Messages(object):
                [] (struct): the sending results for a single recipient::
                    [].email (string): the email address of the recipient
                    [].status (string): the sending status of the recipient - either "sent", "queued", "rejected", or "invalid"
+                   []._id (string): the message's unique id
 
 
         Raises:
